@@ -41,8 +41,8 @@ HMDparse <- function(DF, filepath){
 		Pluses      <- grepl(pattern = "\\+", DF$Year )
 		Minuses     <- grepl(pattern = "\\-", DF$Year )
 		# split out DF into two parts sum(Minuses) 
-		Jan1i       <- DF$Year %in% as.character(all.years[-length(all.years)]) | Minuses
-		Dec31i      <- DF$Year %in% as.character(all.years[-1]) | Pluses
+		Jan1i       <- DF$Year %in% as.character(all.years[-length(all.years)]) | Pluses
+		Dec31i      <- DF$Year %in% as.character(all.years[-1]) | Minuses
 		Jan1        <- DF[Jan1i, ]
 		Dec31       <- DF[Dec31i, ]
 		
@@ -99,17 +99,26 @@ getHMDcountries <- function(){
 #' 
 #' @return a character vector of 2-digit prefecture codes. Names correspond to the proper names given in the English version of the HMD webpage.
 #' 
-#' @importFrom XML readHTMLTable
+#' @importFrom rvest html_table
+#' @importFrom rvest read_html
+#' @importFrom rvest html_element
 #' 
 #' @export
 #' 
 #' @examples \dontrun{ (prefectures <- getJMDprefectures()) }
 #' 
 getJMDprefectures <- function(){
-	Prefs <- as.matrix(XML::readHTMLTable("http://www.ipss.go.jp/p-toukei/JMD/index-en.html",
-					which = 1, stringsAsFactors = FALSE, skip.rows = c(1:4)))
+  Prefs <- as.matrix( 
+    html_table(
+     html_element(
+      read_html("https://www.ipss.go.jp/p-toukei/JMD/index-en.html"), 
+      "table")
+    )[-c(1:4),1:4])
+	# Prefs <- as.matrix(XML::readHTMLTable("https://www.ipss.go.jp/p-toukei/JMD/index-en.html",
+	# 				which = 1, stringsAsFactors = FALSE, skip.rows = c(1:4)))
 	# get codes. rows read from left to right
-	Prefectures <- sprintf("%.2d", row(Prefs) * 4 + col(Prefs) - 5)
+  Prefectures <- c(matrix(sprintf("%.2d", 0:47), byrow = TRUE, ncol = 4))
+
 	names(Prefectures) <- c(Prefs)
 	Prefectures[order(Prefectures)]
 }
@@ -164,4 +173,4 @@ getHMDitemavail <- function(CNTRY, username, password){
 	item_txt    <- all_links[grepl(all_links,pattern=".txt")]
     item_lookup <- gsub(item_txt, pattern = ".txt", replacement = "")
 	return(item_lookup)
-}
\ No newline at end of file
+}
